@@ -262,11 +262,11 @@ impl<W: Write> Encoder<W> {
     /// By default, progressive encoding uses 4 scans.<br>
     /// Use [set_progressive_scans](Encoder::set_progressive_scans) to use a different number of scans
     pub fn set_progressive(&mut self, progressive: bool) {
-        self.set_progressive_scans(if progressive {
+        self.progressive_scans = if progressive {
             4
         } else {
             0
-        });
+        };
     }
 
     /// Set number of scans per component for progressive encoding
@@ -532,8 +532,11 @@ impl<W: Write> Encoder<W> {
     fn quantize_block(&self, component: &Component, block: &[i16; 64]) -> [i16; 64] {
         let mut q_block = [0i16; 64];
 
+        let table = &self.quantization_tables[component.quantization_table as usize];
+
         for i in 0..64 {
-            q_block[i] = self.quantization_tables[component.quantization_table as usize].quantize(block[ZIGZAG[i] as usize], i);
+            let z = ZIGZAG[i] as usize;
+            q_block[i] = table.quantize(block[z], z);
         }
 
         q_block
@@ -933,7 +936,7 @@ fn get_block(data: &[u8],
             let ix = start_x + (x * col_stride);
             let iy = start_y + (y * row_stride);
 
-            block[y * 8 + x] = data[iy * width + ix] as i16;
+            block[y * 8 + x] = (data[iy * width + ix] as i16) - 128;
         }
     }
 
@@ -999,9 +1002,12 @@ mod tests {
     }
 
     #[test]
-    fn test_progressive_scans_default() {
-        let mut encoder = Encoder::new_file("some.jpeg", 100).unwrap();
+    fn test_set_progressive() {
+        let mut encoder = Encoder::new(vec![], 100);
         encoder.set_progressive(true);
         assert_eq!(encoder.progressive_scans(), Some(4));
+
+        encoder.set_progressive(false);
+        assert_eq!(encoder.progressive_scans(), None);
     }
 }
\ No newline at end of file
